@@ -498,6 +498,6 @@ echo "jupyterhub-singleuser ended gracefully"
             await gen.sleep(1)
 
 
-def get_ec2_address(address_type='public_ipv4') -> str:
+def get_ec2_address(address_type='public-ipv4') -> str:
     response = requests.get(f'http://169.254.169.254/latest/meta-data/{address_type}')
     return response.content.decode('utf-8')
